@@ -1,7 +1,7 @@
 """
 Type annotations for mediapackage service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/type_defs.html)
 
 Usage::
 
@@ -12,11 +12,12 @@ Usage::
     ```
 """
 import sys
-from typing import Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     AdMarkersType,
     AdsOnDeliveryRestrictionsType,
+    AdTriggersElementType,
     EncryptionMethodType,
     ManifestLayoutType,
     OriginationType,
@@ -26,7 +27,6 @@ from .literals import (
     StatusType,
     StreamOrderType,
     UtcTimingType,
-    __AdTriggersElementType,
 )
 
 if sys.version_info >= (3, 8):
@@ -45,14 +45,23 @@ __all__ = (
     "CmafEncryptionTypeDef",
     "CmafPackageCreateOrUpdateParametersTypeDef",
     "CmafPackageTypeDef",
+    "ConfigureLogsRequestRequestTypeDef",
     "ConfigureLogsResponseTypeDef",
+    "CreateChannelRequestRequestTypeDef",
     "CreateChannelResponseTypeDef",
+    "CreateHarvestJobRequestRequestTypeDef",
     "CreateHarvestJobResponseTypeDef",
+    "CreateOriginEndpointRequestRequestTypeDef",
     "CreateOriginEndpointResponseTypeDef",
     "DashEncryptionTypeDef",
     "DashPackageTypeDef",
+    "DeleteChannelRequestRequestTypeDef",
+    "DeleteOriginEndpointRequestRequestTypeDef",
+    "DescribeChannelRequestRequestTypeDef",
     "DescribeChannelResponseTypeDef",
+    "DescribeHarvestJobRequestRequestTypeDef",
     "DescribeHarvestJobResponseTypeDef",
+    "DescribeOriginEndpointRequestRequestTypeDef",
     "DescribeOriginEndpointResponseTypeDef",
     "EgressAccessLogsTypeDef",
     "EncryptionContractConfigurationTypeDef",
@@ -64,20 +73,31 @@ __all__ = (
     "HlsPackageTypeDef",
     "IngestEndpointTypeDef",
     "IngressAccessLogsTypeDef",
+    "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListHarvestJobsRequestRequestTypeDef",
     "ListHarvestJobsResponseTypeDef",
+    "ListOriginEndpointsRequestRequestTypeDef",
     "ListOriginEndpointsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "MssEncryptionTypeDef",
     "MssPackageTypeDef",
     "OriginEndpointTypeDef",
     "PaginatorConfigTypeDef",
+    "ResponseMetadataTypeDef",
+    "RotateChannelCredentialsRequestRequestTypeDef",
     "RotateChannelCredentialsResponseTypeDef",
+    "RotateIngestEndpointCredentialsRequestRequestTypeDef",
     "RotateIngestEndpointCredentialsResponseTypeDef",
     "S3DestinationTypeDef",
     "SpekeKeyProviderTypeDef",
     "StreamSelectionTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateChannelRequestRequestTypeDef",
     "UpdateChannelResponseTypeDef",
+    "UpdateOriginEndpointRequestRequestTypeDef",
     "UpdateOriginEndpointResponseTypeDef",
 )
 
@@ -127,7 +147,7 @@ CmafPackageCreateOrUpdateParametersTypeDef = TypedDict(
     "CmafPackageCreateOrUpdateParametersTypeDef",
     {
         "Encryption": "CmafEncryptionTypeDef",
-        "HlsManifests": List["HlsManifestCreateOrUpdateParametersTypeDef"],
+        "HlsManifests": Sequence["HlsManifestCreateOrUpdateParametersTypeDef"],
         "SegmentDurationSeconds": int,
         "SegmentPrefix": str,
         "StreamSelection": "StreamSelectionTypeDef",
@@ -147,6 +167,28 @@ CmafPackageTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredConfigureLogsRequestRequestTypeDef = TypedDict(
+    "_RequiredConfigureLogsRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalConfigureLogsRequestRequestTypeDef = TypedDict(
+    "_OptionalConfigureLogsRequestRequestTypeDef",
+    {
+        "EgressAccessLogs": "EgressAccessLogsTypeDef",
+        "IngressAccessLogs": "IngressAccessLogsTypeDef",
+    },
+    total=False,
+)
+
+
+class ConfigureLogsRequestRequestTypeDef(
+    _RequiredConfigureLogsRequestRequestTypeDef, _OptionalConfigureLogsRequestRequestTypeDef
+):
+    pass
+
+
 ConfigureLogsResponseTypeDef = TypedDict(
     "ConfigureLogsResponseTypeDef",
     {
@@ -157,10 +199,32 @@ ConfigureLogsResponseTypeDef = TypedDict(
         "Id": str,
         "IngressAccessLogs": "IngressAccessLogsTypeDef",
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChannelRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChannelRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
 
+
+class CreateChannelRequestRequestTypeDef(
+    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
+):
+    pass
+
+
 CreateChannelResponseTypeDef = TypedDict(
     "CreateChannelResponseTypeDef",
     {
@@ -171,8 +235,19 @@ CreateChannelResponseTypeDef = TypedDict(
         "Id": str,
         "IngressAccessLogs": "IngressAccessLogsTypeDef",
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateHarvestJobRequestRequestTypeDef = TypedDict(
+    "CreateHarvestJobRequestRequestTypeDef",
+    {
+        "EndTime": str,
+        "Id": str,
+        "OriginEndpointId": str,
+        "S3Destination": "S3DestinationTypeDef",
+        "StartTime": str,
     },
-    total=False,
 )
 
 CreateHarvestJobResponseTypeDef = TypedDict(
@@ -187,10 +262,44 @@ CreateHarvestJobResponseTypeDef = TypedDict(
         "S3Destination": "S3DestinationTypeDef",
         "StartTime": str,
         "Status": StatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateOriginEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateOriginEndpointRequestRequestTypeDef",
+    {
+        "ChannelId": str,
+        "Id": str,
+    },
+)
+_OptionalCreateOriginEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateOriginEndpointRequestRequestTypeDef",
+    {
+        "Authorization": "AuthorizationTypeDef",
+        "CmafPackage": "CmafPackageCreateOrUpdateParametersTypeDef",
+        "DashPackage": "DashPackageTypeDef",
+        "Description": str,
+        "HlsPackage": "HlsPackageTypeDef",
+        "ManifestName": str,
+        "MssPackage": "MssPackageTypeDef",
+        "Origination": OriginationType,
+        "StartoverWindowSeconds": int,
+        "Tags": Mapping[str, str],
+        "TimeDelaySeconds": int,
+        "Whitelist": Sequence[str],
     },
     total=False,
 )
 
+
+class CreateOriginEndpointRequestRequestTypeDef(
+    _RequiredCreateOriginEndpointRequestRequestTypeDef,
+    _OptionalCreateOriginEndpointRequestRequestTypeDef,
+):
+    pass
+
+
 CreateOriginEndpointResponseTypeDef = TypedDict(
     "CreateOriginEndpointResponseTypeDef",
     {
@@ -210,8 +319,8 @@ CreateOriginEndpointResponseTypeDef = TypedDict(
         "TimeDelaySeconds": int,
         "Url": str,
         "Whitelist": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredDashEncryptionTypeDef = TypedDict(
@@ -236,14 +345,14 @@ class DashEncryptionTypeDef(_RequiredDashEncryptionTypeDef, _OptionalDashEncrypt
 DashPackageTypeDef = TypedDict(
     "DashPackageTypeDef",
     {
-        "AdTriggers": List[__AdTriggersElementType],
+        "AdTriggers": Sequence[AdTriggersElementType],
         "AdsOnDeliveryRestrictions": AdsOnDeliveryRestrictionsType,
         "Encryption": "DashEncryptionTypeDef",
         "ManifestLayout": ManifestLayoutType,
         "ManifestWindowSeconds": int,
         "MinBufferTimeSeconds": int,
         "MinUpdatePeriodSeconds": int,
-        "PeriodTriggers": List[Literal["ADS"]],
+        "PeriodTriggers": Sequence[Literal["ADS"]],
         "Profile": ProfileType,
         "SegmentDurationSeconds": int,
         "SegmentTemplateFormat": SegmentTemplateFormatType,
@@ -255,6 +364,27 @@ DashPackageTypeDef = TypedDict(
     total=False,
 )
 
+DeleteChannelRequestRequestTypeDef = TypedDict(
+    "DeleteChannelRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+DeleteOriginEndpointRequestRequestTypeDef = TypedDict(
+    "DeleteOriginEndpointRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+DescribeChannelRequestRequestTypeDef = TypedDict(
+    "DescribeChannelRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 DescribeChannelResponseTypeDef = TypedDict(
     "DescribeChannelResponseTypeDef",
     {
@@ -265,8 +395,15 @@ DescribeChannelResponseTypeDef = TypedDict(
         "Id": str,
         "IngressAccessLogs": "IngressAccessLogsTypeDef",
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeHarvestJobRequestRequestTypeDef = TypedDict(
+    "DescribeHarvestJobRequestRequestTypeDef",
+    {
+        "Id": str,
     },
-    total=False,
 )
 
 DescribeHarvestJobResponseTypeDef = TypedDict(
@@ -281,8 +418,15 @@ DescribeHarvestJobResponseTypeDef = TypedDict(
         "S3Destination": "S3DestinationTypeDef",
         "StartTime": str,
         "Status": StatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeOriginEndpointRequestRequestTypeDef = TypedDict(
+    "DescribeOriginEndpointRequestRequestTypeDef",
+    {
+        "Id": str,
     },
-    total=False,
 )
 
 DescribeOriginEndpointResponseTypeDef = TypedDict(
@@ -304,8 +448,8 @@ DescribeOriginEndpointResponseTypeDef = TypedDict(
         "TimeDelaySeconds": int,
         "Url": str,
         "Whitelist": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EgressAccessLogsTypeDef = TypedDict(
@@ -380,7 +524,7 @@ _OptionalHlsManifestCreateOrUpdateParametersTypeDef = TypedDict(
     "_OptionalHlsManifestCreateOrUpdateParametersTypeDef",
     {
         "AdMarkers": AdMarkersType,
-        "AdTriggers": List[__AdTriggersElementType],
+        "AdTriggers": Sequence[AdTriggersElementType],
         "AdsOnDeliveryRestrictions": AdsOnDeliveryRestrictionsType,
         "IncludeIframeOnlyStream": bool,
         "ManifestName": str,
@@ -428,7 +572,7 @@ HlsPackageTypeDef = TypedDict(
     "HlsPackageTypeDef",
     {
         "AdMarkers": AdMarkersType,
-        "AdTriggers": List[__AdTriggersElementType],
+        "AdTriggers": Sequence[AdTriggersElementType],
         "AdsOnDeliveryRestrictions": AdsOnDeliveryRestrictionsType,
         "Encryption": "HlsEncryptionTypeDef",
         "IncludeIframeOnlyStream": bool,
@@ -461,11 +605,31 @@ IngressAccessLogsTypeDef = TypedDict(
     total=False,
 )
 
+ListChannelsRequestRequestTypeDef = TypedDict(
+    "ListChannelsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListChannelsResponseTypeDef = TypedDict(
     "ListChannelsResponseTypeDef",
     {
         "Channels": List["ChannelTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListHarvestJobsRequestRequestTypeDef = TypedDict(
+    "ListHarvestJobsRequestRequestTypeDef",
+    {
+        "IncludeChannelId": str,
+        "IncludeStatus": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -475,6 +639,16 @@ ListHarvestJobsResponseTypeDef = TypedDict(
     {
         "HarvestJobs": List["HarvestJobTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListOriginEndpointsRequestRequestTypeDef = TypedDict(
+    "ListOriginEndpointsRequestRequestTypeDef",
+    {
+        "ChannelId": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
@@ -484,16 +658,23 @@ ListOriginEndpointsResponseTypeDef = TypedDict(
     {
         "NextToken": str,
         "OriginEndpoints": List["OriginEndpointTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
     },
-    total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 MssEncryptionTypeDef = TypedDict(
@@ -547,6 +728,24 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+RotateChannelCredentialsRequestRequestTypeDef = TypedDict(
+    "RotateChannelCredentialsRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 RotateChannelCredentialsResponseTypeDef = TypedDict(
     "RotateChannelCredentialsResponseTypeDef",
     {
@@ -557,8 +756,16 @@ RotateChannelCredentialsResponseTypeDef = TypedDict(
         "Id": str,
         "IngressAccessLogs": "IngressAccessLogsTypeDef",
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+RotateIngestEndpointCredentialsRequestRequestTypeDef = TypedDict(
+    "RotateIngestEndpointCredentialsRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IngestEndpointId": str,
     },
-    total=False,
 )
 
 RotateIngestEndpointCredentialsResponseTypeDef = TypedDict(
@@ -571,8 +778,8 @@ RotateIngestEndpointCredentialsResponseTypeDef = TypedDict(
         "Id": str,
         "IngressAccessLogs": "IngressAccessLogsTypeDef",
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 S3DestinationTypeDef = TypedDict(
@@ -589,7 +796,7 @@ _RequiredSpekeKeyProviderTypeDef = TypedDict(
     {
         "ResourceId": str,
         "RoleArn": str,
-        "SystemIds": List[str],
+        "SystemIds": Sequence[str],
         "Url": str,
     },
 )
@@ -617,6 +824,43 @@ StreamSelectionTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Mapping[str, str],
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
+_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateChannelRequestRequestTypeDef(
+    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
+):
+    pass
+
+
 UpdateChannelResponseTypeDef = TypedDict(
     "UpdateChannelResponseTypeDef",
     {
@@ -627,10 +871,42 @@ UpdateChannelResponseTypeDef = TypedDict(
         "Id": str,
         "IngressAccessLogs": "IngressAccessLogsTypeDef",
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateOriginEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateOriginEndpointRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalUpdateOriginEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateOriginEndpointRequestRequestTypeDef",
+    {
+        "Authorization": "AuthorizationTypeDef",
+        "CmafPackage": "CmafPackageCreateOrUpdateParametersTypeDef",
+        "DashPackage": "DashPackageTypeDef",
+        "Description": str,
+        "HlsPackage": "HlsPackageTypeDef",
+        "ManifestName": str,
+        "MssPackage": "MssPackageTypeDef",
+        "Origination": OriginationType,
+        "StartoverWindowSeconds": int,
+        "TimeDelaySeconds": int,
+        "Whitelist": Sequence[str],
     },
     total=False,
 )
 
+
+class UpdateOriginEndpointRequestRequestTypeDef(
+    _RequiredUpdateOriginEndpointRequestRequestTypeDef,
+    _OptionalUpdateOriginEndpointRequestRequestTypeDef,
+):
+    pass
+
+
 UpdateOriginEndpointResponseTypeDef = TypedDict(
     "UpdateOriginEndpointResponseTypeDef",
     {
@@ -650,6 +926,6 @@ UpdateOriginEndpointResponseTypeDef = TypedDict(
         "TimeDelaySeconds": int,
         "Url": str,
         "Whitelist": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
